unofficial mirror of guix-devel@gnu.org 
 help / color / mirror / code / Atom feed
* [PATCH] gnu: sqlite: Enable DBSTAT_VTAB.
@ 2016-08-30 23:34 David Craven
  2016-08-30 23:34 ` [PATCH] gnu: sqlite: Update to 3.14.1 David Craven
  2016-08-31 18:52 ` [PATCH] gnu: sqlite: Enable DBSTAT_VTAB Leo Famulari
  0 siblings, 2 replies; 6+ messages in thread
From: David Craven @ 2016-08-30 23:34 UTC (permalink / raw)
  To: guix-devel

* gnu/packages/databases.scm (sqlite)[arguments]: Enable configure-flag
  -DSQLITE_ENABLE_DBSTAT_VTAB.
---
 gnu/packages/databases.scm | 10 ++++++----
 1 file changed, 6 insertions(+), 4 deletions(-)

diff --git a/gnu/packages/databases.scm b/gnu/packages/databases.scm
index a04c375..ce51d28 100644
--- a/gnu/packages/databases.scm
+++ b/gnu/packages/databases.scm
@@ -520,10 +520,12 @@ for example from a shell script.")
    (inputs `(("readline" ,readline)))
    (arguments
     `(#:configure-flags
-      ;; Add -DSQLITE_SECURE_DELETE and -DSQLITE_ENABLE_UNLOCK_NOTIFY to
-      ;; CFLAGS.  GNU Icecat will refuse to use the system SQLite unless these
-      ;; options are enabled.
-      '("CFLAGS=-O2 -DSQLITE_SECURE_DELETE -DSQLITE_ENABLE_UNLOCK_NOTIFY")))
+      ;; Add -DSQLITE_SECURE_DELETE, -DSQLITE_ENABLE_UNLOCK_NOTIFY and
+      ;; -DSQLITE_ENABLE_DBSTAT_VTAB to CFLAGS.  GNU Icecat will refuse
+      ;; to use the system SQLite unless these options are enabled.
+      (list (string-append "CFLAGS=-O2 -DSQLITE_SECURE_DELETE "
+                           "-DSQLITE_ENABLE_UNLOCK_NOTIFY "
+                           "-DSQLITE_ENABLE_DBSTAT_VTAB"))))
    (home-page "http://www.sqlite.org/")
    (synopsis "The SQLite database management system")
    (description
-- 
2.9.0

^ permalink raw reply related	[flat|nested] 6+ messages in thread

end of thread, other threads:[~2016-09-01 21:03 UTC | newest]

Thread overview: 6+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2016-08-30 23:34 [PATCH] gnu: sqlite: Enable DBSTAT_VTAB David Craven
2016-08-30 23:34 ` [PATCH] gnu: sqlite: Update to 3.14.1 David Craven
2016-08-31 18:50   ` Leo Famulari
2016-08-31 18:52 ` [PATCH] gnu: sqlite: Enable DBSTAT_VTAB Leo Famulari
2016-09-01 20:41   ` Mark H Weaver
2016-09-01 21:03     ` David Craven

Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/guix.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).